@@ -28,33 +28,34 @@
 #include <gnome.h>
 #include <gtk/gtk.h>
 
-#include "xst.h"
+#include "gst.h"
 
+#include "table.h"
 #include "users-table.h"
 #include "user_group.h"
 #include "callbacks.h"
 #include "user-group-xml.h"
 
-TableConfig users_table_config [] = {
-	/*Column name,          Adv_state_show,	Basic_state_show*/
-	{ "User",		TRUE,		TRUE},
-	{ "UID",		TRUE,		FALSE},
-	{ "Home",		TRUE,		FALSE},
-	{ "Shell",		TRUE,		FALSE},
-	{ "Comments",		FALSE,		TRUE},
-	{ "Group",		FALSE,		TRUE},
-//	{ "GID",		FALSE,		FALSE},
-	{NULL}
-};
-
-extern XstTool *tool;
+extern GstTool *tool;
 
 GtkWidget *users_table;
 GArray *users_array;
 
+TableConfig users_table_config [] = {
+	/*Column name,          Adv_state_show,	Basic_state_show*/
+	{ N_("User"),		TRUE,		TRUE},
+	{ N_("UID"),		TRUE,		FALSE},
+	{ N_("Home"),		TRUE,		FALSE},
+	{ N_("Shell"),		TRUE,		FALSE},
+	{ N_("Comments"),	FALSE,		TRUE},
+	{ N_("Group"),		FALSE,		TRUE},
+	{NULL}
+};
+
 static void
 add_user_columns (GtkTreeView *treeview)
 {
+	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
 	TableConfig *i;
 	guint j;
@@ -64,15 +65,16 @@ add_user_columns (GtkTreeView *treeview)
 	     i++, j++)
 	{	
 		renderer = gtk_cell_renderer_text_new ();
-		g_object_set (G_OBJECT (renderer), "xalign", 0.0, NULL);
 	
-		gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-	                                                     -1,
-	                                                     i->name,
-	                                                     renderer,
-	                                                     "text",
-	                                                     j,
-	                                                     NULL);
+		column = gtk_tree_view_column_new_with_attributes (_(i->name),
+	                                                           renderer,
+	                                                           "text",
+	                                                           j,
+	                                                           NULL);
+		gtk_tree_view_column_set_resizable (column, TRUE);
+		gtk_tree_view_column_set_sort_column_id (column, j);
+
+		gtk_tree_view_insert_column (GTK_TREE_VIEW (users_table), column, j);
 	}
 }
 
@@ -88,53 +90,47 @@ create_users_model (void)
 	                            G_TYPE_STRING,
 	                            G_TYPE_STRING,
 	                            G_TYPE_STRING,
-	                            G_TYPE_INT);
+	                            G_TYPE_INT,
+	                            G_TYPE_POINTER);
 	return GTK_TREE_MODEL (model);
 }
 
-static GtkWidget*
+
+
+void
 create_users_table (void)
 {
+	GtkTreeSelection *selection;
 	GtkTreeModel *model;
+	GtkItemFactory *item_factory;
 	
 	model = create_users_model ();
 	
-	users_table = gtk_tree_view_new_with_model (model);
+	users_table = gst_dialog_get_widget (tool->main_dialog, "users_table");
+	gtk_tree_view_set_model (GTK_TREE_VIEW (users_table), model);
 	
 	g_object_unref (model);
 	
-        gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (users_table), TRUE);
-
 	add_user_columns (GTK_TREE_VIEW (users_table));
 	
-	gtk_signal_connect (GTK_OBJECT (users_table),
-	                    "cursor_changed",
-	                    G_CALLBACK (on_user_table_clicked),
-	                    NULL);
-	
-	return users_table;
-}
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (users_table));
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 
-void 
-construct_users_table (void)
-{
-	GtkWidget *sw;
-	GtkWidget *list;
-	
-	sw = xst_dialog_get_widget (tool->main_dialog, "users_table");
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
-	
-	list = create_users_table ();
-	
-	gtk_widget_show_all (list);
-	gtk_container_add (GTK_CONTAINER (sw), list);
+	item_factory = popup_item_factory_create (users_table);
+
+	g_signal_connect (G_OBJECT (selection), "changed",
+			  G_CALLBACK (on_table_clicked),
+			  (gpointer) users_table);
+	g_signal_connect (G_OBJECT (users_table), "button_press_event",
+			  G_CALLBACK (on_table_button_press),
+			  (gpointer) item_factory);
 }
 
 static char*
 users_table_value (xmlNodePtr node, gchar *key)
 {
         g_return_val_if_fail (node != NULL, NULL);
-        return xst_xml_get_child_content (node, key);
+        return gst_xml_get_child_content (node, key);
 }
 
 static UserTreeItem*
@@ -156,16 +152,18 @@ void
 populate_users_table (void)
 {
 	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (users_table));
-	xmlNodePtr root = get_user_root_node ();
+	xmlNodePtr root = get_root_node (NODE_USER);
 	GtkTreeIter iter;
 	xmlNodePtr user;
-	
+
 	g_return_if_fail (model != NULL);
 	g_return_if_fail (root != NULL);
+
+	gtk_tree_store_clear (GTK_TREE_STORE (model));
 	
 	users_array = g_array_new (FALSE, FALSE, sizeof (xmlNodePtr));
 	
-	for (user = xst_xml_element_find_first (root, "user"); user != NULL; user = xst_xml_element_find_next (user, "user"))
+	for (user = gst_xml_element_find_first (root, "user"); user != NULL; user = gst_xml_element_find_next (user, "user"))
 	{
 		if (check_node_visibility (user))
 		{
@@ -181,21 +179,29 @@ populate_users_table (void)
 					    COL_USER_SHELL, item->shell,
 					    COL_USER_COMMENT, item->comment,
 					    COL_USER_GROUP, item->group,
+			                    COL_USER_POINTER, user,
 					    -1);
 		}
 	}
 }
 
 void
-update_users_table_complexity (XstDialogComplexity complexity)
+update_users_table_complexity (GstDialogComplexity complexity)
 {
 	GtkTreeView *u_table = GTK_TREE_VIEW (users_table);
+	GtkTreeView *g_table = GTK_TREE_VIEW (gst_dialog_get_widget (tool->main_dialog, "groups_table"));
 	GtkTreeViewColumn *column;
 	TableConfig *i;
 	guint j;
+
+	gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (u_table));
+	gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (g_table));
+
+	actions_set_sensitive (NODE_USER, FALSE);
+	actions_set_sensitive (NODE_GROUP, FALSE);
 	
 	switch (complexity) {
-	case XST_DIALOG_BASIC:
+	case GST_DIALOG_BASIC:
 		for (i = users_table_config, j=0;
 		     i->name != NULL;
 		     i++, j++)
@@ -204,7 +210,7 @@ update_users_table_complexity (XstDialogComplexity complexity)
 			gtk_tree_view_column_set_visible (column, i->basic_state_showable);
 		}
 		break;
-	case XST_DIALOG_ADVANCED:
+	case GST_DIALOG_ADVANCED:
 		for (i = users_table_config, j=0;
 		     i->name != NULL;
 		     i++, j++)
